@@ -2,6 +2,45 @@ from django.core.exceptions import FieldDoesNotExist
 from django.db import models
 
 
+def quickregister(urlpatterns, model, menugroup=None):
+    import htmlgenerator as hg
+
+    from bread import menu
+    from bread.utils.links import Link, ModelHref
+    from bread.utils.urls import default_model_paths
+    from bread.views import BrowseView
+
+    urlpatterns.extend(
+        default_model_paths(
+            model,
+            browseview=BrowseView._with(
+                rowactions=(
+                    Link(
+                        href=ModelHref(
+                            model,
+                            "edit",
+                            kwargs={"pk": hg.C("row.id")},
+                            query={"next": hg.C("request.get_full_path")},
+                        ),
+                        label="Edit",
+                        iconname="edit",
+                    ),
+                )
+            ),
+        )
+    )
+
+    menu.registeritem(
+        menu.Item(
+            Link(
+                ModelHref(model, "browse"),
+                model._meta.verbose_name_plural.title(),
+            ),
+            model._meta.app_label.title() if menugroup is None else menugroup,
+        )
+    )
+
+
 def pretty_modelname(model, plural=False):
     """Canonical way to pretty print a model name"""
     if plural:
@@ -53,8 +92,14 @@ def resolve_modellookup(model, accessor):
                 attrib = attrib._meta.get_field(attribstr)
             except FieldDoesNotExist:
                 attrib = getattr(attrib, attribstr)
+        elif isinstance(attrib, models.fields.reverse_related.ForeignObjectRel):
+            try:
+                attrib = attrib.related_model._meta.get_field(attribstr)
+            except FieldDoesNotExist:
+                attrib = getattr(attrib.related_model, attribstr)
         else:
             try:
+                breakpoint()
                 attrib = attrib[attribstr]
             except (TypeError, AttributeError, KeyError, ValueError, IndexError):
                 attrib = getattr(attrib, attribstr)
